@@ -1,5 +1,3 @@
-/* $Id: procmap.c,v 1.22 2006/06/24 17:45:29 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -45,7 +43,7 @@ static const unsigned long _glibtop_sysdeps_map_device =
 /* Init function. */
 
 void
-glibtop_init_proc_map_s (glibtop *server)
+_glibtop_init_proc_map_s (glibtop *server)
 {
 	server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
 }
